@@ -1,18 +1,21 @@
+"""
+Module for the CaitNode class, which wraps AST nodes.
+"""
 import ast
 from pedal.cait.ast_helpers import dump
 from types import MethodType
+
+from pedal.core.location import Location
 from pedal.core.report import MAIN_REPORT
 
 
 class CaitNode:
     """
     A wrapper class for AST nodes. Linearizes access to the children of the ast
-    node and saves the field this AST node
-    originated from.
+    node and saves the field this AST node originated from.
 
     Attributes:
-        ast_name (str): The name of the original AstNode (e.g., "Name" or
-            "FunctionDef")
+        ast_node (ast.AST): The original AstNode.
 
     TODO: May want to just add fields and methods to the existing AST nodes and
     use a production pattern instead.
@@ -150,6 +153,8 @@ class CaitNode:
                 return eval_unop(op_num, op_expr)
             if op_expr.ast_name == "Num":
                 return op_expr.n
+            if op_expr.ast_name == "Constant":
+                return op_expr.value
             raise NotImplementedError
 
         def eval_bool_comp(num_list, comp_ast):
@@ -223,16 +228,22 @@ class CaitNode:
 
         try:
             ins_expr = CaitNode(ast.parse(expr), report=self.report).body[0].value
-            ins_nums = ins_expr.find_all("Num")
-            std_nums = self.find_all("Num")
+            ins_nums = ins_expr.find_all(["Num", "Constant"])
+            std_nums = self.find_all(["Num", "Constant"])
             test_nums = []
             for num in ins_nums:
-                raw_num = num.n
+                if hasattr(num, "n"):
+                    raw_num = num.n
+                else:
+                    raw_num = num.value
                 test_nums.append(raw_num)
                 test_nums.append(raw_num + mag)
                 test_nums.append(raw_num - mag)
             for num in std_nums:
-                raw_num = num.n
+                if hasattr(num, "n"):
+                    raw_num = num.n
+                else:
+                    raw_num = num.value
                 test_nums.append(raw_num)
                 test_nums.append(raw_num + mag)
                 test_nums.append(raw_num - mag)
@@ -416,8 +427,8 @@ class CaitNode:
         matcher = stm.StretchyTreeMatcher(pattern, report=self.report)
         if (not is_node and not is_mod) and len(matcher.root_node.children) != 1:
             raise ValueError("pattern does not evaluate to a singular statement")
-        prev_match = self.map if use_previous else None
-        return matcher.find_matches(self, check_meta=check_meta, pre_match=prev_match)
+        use_previous = self.map if use_previous else None
+        return matcher.find_matches(self, check_meta=check_meta, use_previous=use_previous)
 
     def find_match(self, pattern, is_mod=False, check_meta=True, use_previous=True):
         """
@@ -448,9 +459,7 @@ class CaitNode:
         """
         items = []
         visitor = ast.NodeVisitor()
-        # setattr(visitor, "current_id", self.tree_id - 1)
         setattr(visitor, "items", items)
-        func_name = 'visit_' + node_type
 
         def main_visit(self, node):
             """
@@ -465,35 +474,50 @@ class CaitNode:
             self.items.append(node.cait_node)
             return self.generic_visit(node)
 
-        func_ref = main_visit
-        setattr(visitor, func_name, MethodType(func_ref, visitor))
+        if type(node_type) is not list:
+            node_type_list = [node_type]
+        else:
+            node_type_list = node_type
+
+        for node_t in node_type_list:
+            func_name = 'visit_' + node_t
+            func_ref = main_visit
+            setattr(visitor, func_name, MethodType(func_ref, visitor))
+
         visitor.visit(self.astNode)
         return visitor.items
 
     def has(self, node):
         """
-        Determine if this node has the given `node`.
+        Determine if this node has the given `node`. Specifically, it checks if the ast has a given Constant or variable
+        This method does NOT check for equality of two asts. Use find_matches for that functionality
+        Args:
+            node (): A constant (int, float, str), or Name astnode
+
+        Returns: True if found, False otherwise
+
         """
-        if isinstance(node, (int, float)):
+        if isinstance(node, (int, float, str)):
             visitor = ast.NodeVisitor()
-            has_num = []
+            has_constant = []
+
+            def visit_Constant(self, potential):
+                has_constant.append(node == potential.value)
+                return self.generic_visit(potential)
 
             def visit_Num(self, potential):
-                """
+                has_constant.append(node == potential.n)
+                return self.generic_visit(potential)
 
-                Args:
-                    self:
-                    potential:
-
-                Returns:
-
-                """
-                has_num.append(node == potential.n)
+            def visit_Str(self, potential):
+                has_constant.append(node == potential.s)
                 return self.generic_visit(potential)
 
             visitor.visit_Num = MethodType(visit_Num, visitor)
+            visitor.visit_Constant = MethodType(visit_Constant, visitor)
+            visitor.visit_Str = MethodType(visit_Str, visitor)
             visitor.visit(self.astNode)
-            return any(has_num)
+            return any(has_constant)
         elif node.ast_name != "Name":
             return False
         visitor = ast.NodeVisitor()
@@ -539,9 +563,20 @@ class CaitNode:
         Returns:
             bool: True if this node's ast name matches the specified one
         """
+        # TODO: Deal with this compatibility issue in a more elegant way
         if not isinstance(ast_name, str):
             ast_name = CaitNode.get_ast_name(ast_name.astNode)
-        return CaitNode.get_ast_name(self.astNode).lower() == ast_name.lower()
+        self_name = CaitNode.get_ast_name(self.astNode).lower()
+        other_name = ast_name.lower()
+        evaluation = self_name == other_name
+        if self_name == "constant" and other_name in ["num", "str", "bytes"]:
+            if other_name == "num" and type(self.n) in [float, int]:
+                evaluation = True
+            elif other_name == "str" and type(self.s) is str:
+                evaluation = True
+            elif other_name == "bytes" and type(self.s) is bytes:
+                evaluation = True
+        return evaluation
 
     def is_method(self):
         """
@@ -573,7 +608,7 @@ class CaitNode:
         if self.ast_name != "Name":
             return None
         try:
-            return self.report['tifa']["top_level_variables"][self.id]
+            return self.report['tifa']['latest'].top_level_variables[self.id]
         except KeyError:
             return None
 
@@ -611,11 +646,20 @@ class CaitNode:
             value = self.n
         elif self.is_ast("Str"):
             value = self.s
+        elif self.is_ast("Constant"):
+            value = self.value
         elif self.is_ast("Name"):
             # TODO: Decide on what this should return...
             value = self.id
         return value
 
+    def locate(self):
+        """
+        Returns:
+            pedal.core.Location: The location of this node.
+        """
+        return Location(self.astNode.lineno, col=self.astNode.col_offset)
+
 
 AST_SINGLE_FUNCTIONS = ["ctx_name", "op_name"]
 AST_ARRAYS_OF_FUNCTIONS = ["ops_names"]
