@@ -61,7 +61,7 @@ def _split_into_lolos(a_string) -> 'List[List[str]]':
 
     Returns: The list of list of strings
     """
-    return [list(line) for line in s.split("\n")]
+    return [list(line) for line in a_string.split("\n")]
 
 
 def _normalize_string(a_string, numeric_endings=False):
@@ -195,3 +195,11 @@ def _are_sets_equal(x, y, _exact_strings, _delta):
         if not _set_contains(x_element, y, _exact_strings, _delta):
             return False
     return True
+
+
+def iterable(obj) -> bool:
+    """
+    Determines if this object satisfies the iterable interface, which
+    requires it to support either ``__iter__`` or ``__getitem__``.
+    """
+    return hasattr(obj, '__iter__') or hasattr(obj, '__getitem__')
